#
# spec file for package libXfixes
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libXfixes3
Name:           libXfixes
Version:        6.0.1
Release:        1.5
Summary:        X11 miscellaneous "fixes" extension library
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://xorg.freedesktop.org/
#Git-Clone:	git://anongit.freedesktop.org/xorg/lib/libXfixes
#Git-Web:	http://cgit.freedesktop.org/xorg/lib/libXfixes/
Source:         https://xorg.freedesktop.org/archive/individual/lib/%name-%version.tar.xz
Source1:        https://xorg.freedesktop.org/archive/individual/lib/%name-%version.tar.xz.sig
Source2:        libXfixes.keyring
Source3:        baselibs.conf
#git#BuildRequires:	autoconf >= 2.60, automake, libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fixesproto) >= 5.0
BuildRequires:  pkgconfig(x11) >= 1.6
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto)

%description
The X Fixes extension provides applications with work-arounds for
various limitations in the core protocol.

%package -n %lname
Summary:        X11 miscellaneous "fixes" extension library
# O/P added for 12.2
Group:          System/Libraries
Provides:       xorg-x11-libXfixes = 7.6_%version-%release
Obsoletes:      xorg-x11-libXfixes < 7.6_%version-%release

%description -n %lname
The X Fixes extension provides applications with work-arounds for
various limitations in the core protocol.

%package devel
Summary:        Development files for the X11 Xfixes extension library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
# O/P added for 12.2
Provides:       xorg-x11-libXfixes-devel = 7.6_%version-%release
Obsoletes:      xorg-x11-libXfixes-devel < 7.6_%version-%release

%description devel
The X Fixes extension provides applications with work-arounds for
various limitations in the core protocol.

This package contains the development headers for the library found
in %lname.

%prep
%setup -q

%build
%configure --disable-static
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%post -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPYING
%_libdir/libXfixes.so.3*

%files devel
%doc README.md
%_includedir/X11/*
%_libdir/libXfixes.so
%_libdir/pkgconfig/xfixes.pc
%_mandir/man3/*

%changelog
* Thu Apr 13 2023 Dirk Müller <dmueller@suse.com>
- add keyring validation
- modernize spec file. install license and documentation
* Mon Apr 10 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 6.0.1
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * Remove unnecessary casts from malloc & free calls
  * Variable scope reduction as recommended by cppcheck
  * Mark two dpy parameters const as suggested by cppcheck
  * Quiet -Wconditional-uninitialized warnings from clang
  * Resolve 36 of 40 -Wextra-semi-stmt warnings from clang
  * Handle 63 of 63 -Wshorten-64-to-32 warnings from clang
  * Handle 60 of 60 -Wimplicit-int-conversion warnings from clang
  * Handle 6 of 9 -Wsign-conversion warnings from clang
  * XFixesCloseDisplay: Mark codes as unused
  * Require LT_INIT from libtool 2 instead of deprecated AC_PROG_LIBTOOL
  * Remove "All rights reserved" from Oracle copyright notices
* Wed Dec  1 2021 Stefan Dirsch <sndirsch@suse.com>
- update to version 6.0 is needed for GNOME41, particularly the
  gnome-settings-daemon's new feature to disconnect from Xwayland
  (JIRA #SLE-22829)
* Wed May 12 2021 Stefan Dirsch <sndirsch@suse.com>
- Update to version 6.0.0
  * The big new feature here is support for the new
    ClientDisconnectMode. From the corresponding
    xorgproto announcement:
    An X server that is started on demand (Xwayland) should ideally
    also terminate when the last client disconnects. However, some
    X11 clients that provide system services will linger around
    forever, preventing that shutdown.
  * With the new XFixes request, a client can designate itself as
    to-be-terminated and the X server can ignore those clients when
    counting the number of remaining clients. If no other clients
    are left, the server can shut down.
  * Note that this requires changes to the X server and each
    client to work.
* Sat Oct 29 2016 tobias.johannes.klausmann@mni.thm.de
- Update to version 5.0.3:
  + fix Integer overflow on illegal server response
* Mon May 30 2016 sndirsch@suse.com
- Update to version 5.0.2
  * Remove fallback for _XEatDataWords, require libX11 1.6 for it
- tagged baselibs.conf as source in specfile
* Wed May 29 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 5.0.1:
  This bug fix release includes the fix for the recently announced
  CVE-2013-1983, along with some other cleanups & warning fixes.
* Thu Apr 11 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Sun Feb 17 2013 jengelh@inai.de
- Use more robust make install call
* Tue Sep 25 2012 sndirsch@suse.com
- specfile cleanup
* Sat Feb 11 2012 jengelh@medozas.de
- Rename xorg-x11-libXfixes to libXfixes and utilize shlib policy
* Fri Mar 18 2011 fcrozat@novell.com
- update to release 5.0
  * Pointer barrier support, along with the usual buildsystem updates.
* Tue Dec 21 2010 sndirsch@novell.com
- bumped version number to 7.6_4.0.5
* Sat Sep  4 2010 sndirsch@novell.com
- update to release 4.0.5
- bumped version number to 7.5_4.0.5
- fixed Summary/Group entries in -devel package
* Sun Apr  4 2010 sndirsch@suse.de
- libXfixes 4.0.4
- bumped version number to 7.5
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Sat May  2 2009 eich@suse.de
- revert static library and .la file removal
  for SUSE versions <= 11.1.
* Tue Apr 21 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Thu Sep 11 2008 sndirsch@suse.de
- bumped release number to 7.4
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Dec 26 2007 crrodriguez@suse.de
- PreReq coreutils
- fix library-without-ldconfig-postun warning
- fix no-version-dependency-on xorg-x11-libXfixes 7.3
* Sat Sep 29 2007 sndirsch@suse.de
- bumped version to 7.3
* Wed Nov  8 2006 sndirsch@suse.de
- update to release 4.0.3 (X.Org 7.2 RC2)
  * Don't unlock the Display when you have not locked it.
* Sat Oct 14 2006 sndirsch@suse.de
- update to X.Org 7.2R1
* Wed Aug  2 2006 sndirsch@suse.de
- fix setup line
* Fri Jul 28 2006 sndirsch@suse.de
- use "-fno-strict-aliasing"
* Thu Jul 27 2006 sndirsch@suse.de
- use $RPM_OPT_FLAGS
- remove existing /usr/include/X11 symlink in %%pre
* Fri Jun 23 2006 sndirsch@suse.de
- created package
